﻿using Moonlight.App.Database.Entities;
using Moonlight.App.Models.Misc;
using Moonlight.App.Services;

namespace Moonlight.App.MalwareScans;

public class SelfBotCodeScan : MalwareScan
{
    public override string Name => "Selfbot code scan";
    public override string Description => "This scan is a simple selfbot code scan provided by moonlight";
    
    public override async Task<MalwareScanResult[]> Scan(Server server, IServiceProvider serviceProvider)
    {
        var serverService = serviceProvider.GetRequiredService<ServerService>();
        var access = await serverService.CreateFileAccess(server, null!);
        var fileElements = await access.Ls();

        foreach (var script in fileElements.Where(x => x.Name.EndsWith(".py") && x.IsFile))
        {
            var rawScript = await access.Read(script);

            if (rawScript.Contains("https://discord.com/api") && !rawScript.Contains("https://discord.com/api/oauth2") && !rawScript.Contains("https://discord.com/api/webhook") || rawScript.Contains("https://rblxwild.com")) //TODO: Export to plugins, add regex for checking
            {
                return new[]
                {
                    new MalwareScanResult
                    {
                        Title = "Potential selfbot",
                        Description = $"Suspicious script file: {script.Name}",
                        Author = "Marcel Baumgartner"
                    }
                };
            }
        }

        return Array.Empty<MalwareScanResult>();
    }
}